#include "dialogconfiguration.h"
#include "ui_dialogconfiguration.h"
#include <QSettings>
#include <QFileDialog>

DialogConfiguration::DialogConfiguration(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DialogConfiguration)
{
    ui->setupUi(this);
    Load();
    connect (ui->pushButtonClose,SIGNAL(clicked(bool)),this,SLOT(close()));
    connect(ui->pushButtonSave,SIGNAL(clicked(bool)),this,SLOT(Save()));
    connect(ui->toolButtonStorageDirectory,SIGNAL(clicked(bool)),this,SLOT(SetStorageDirectory()));
}

DialogConfiguration::~DialogConfiguration()
{
    delete ui;
}

qlonglong DialogConfiguration::getCitiesSize()
{
    QSettings s;
    return s.value("CitiesSize",540426).toLongLong();
}

qlonglong DialogConfiguration::getFirstnameSize()
{
    QSettings s;
    return s.value("FirstnameSize",68090).toLongLong();
}


qlonglong DialogConfiguration::getFortuneSize()
{
    QSettings s;
    return s.value("FortuneSize",239163).toLongLong();
}

qlonglong DialogConfiguration::getLexiqueSize()
{
    QSettings s;
    return s.value("LexiqueSize",5553792).toLongLong();
}


qlonglong DialogConfiguration::getWikiquoteSize()
{
    QSettings s;
    return s.value("WikiquoteSize",10328072).toLongLong();
}

qlonglong DialogConfiguration::getWikionarySize()
{
    QSettings s;
    return s.value("WiktionarySize",1322268337).toLongLong();
}


QString DialogConfiguration::getCitiesLocation()
{
   QSettings s;
   return s.value("CitiesLocation","https://www.insee.fr/fr/statistiques/fichier/2114819/comsimp2016-txt.zip").toString();
}

QString DialogConfiguration::getFirstnameLocation()
{
    QSettings s;
    return s.value("FirstnameLocation","http://www.lexique.org/public/Prenoms100.zip").toString();
}

QString DialogConfiguration::getFortuneLocation()
{
    QSettings s;
    return s.value("FortuneLocation","http://www.fortunes-fr.org/fortunes-fr/fortunes-fr-0.02.tar.gz").toString();
}

QString DialogConfiguration::getLexiqueLocation()
{
    QSettings s;
    return s.value("LexiqueLocation","http://www.lexique.org/public/Lexique381.zip").toString();
}

QString DialogConfiguration::getWikiquoteLocation()
{
    QSettings s;
    return s.value("WikiquoteLocation","http://download.wikimedia.org/frwikiquote/latest/frwikiquote-latest-pages-articles.xml.bz2").toString();
}

QString DialogConfiguration::getWikionaryLocation()
{
    QSettings s;
    return s.value("WiktionaryLocation","http://download.wikimedia.org/frwiktionary/latest/frwiktionary-latest-pages-articles.xml.bz2").toString();
}



QString DialogConfiguration::getStorageDirectory()
{
    QSettings s;
    return s.value("StorageDirectory").toString();
}

void DialogConfiguration::SetStorageDirectory()
{
    ui->lineEditStorageDirectory->setText(QFileDialog::getExistingDirectory(this,tr("Enter directory to save the file donloaded"),QDir::homePath()));
}


void DialogConfiguration::Save()
{
    QSettings s;
    s.setValue("CitiesLocation",ui->lineEditCities->text());
    s.setValue("FirstnameLocation",ui->lineEditFirstname->text());
    s.setValue("FortuneLocation",ui->lineEditFortune->text());
    s.setValue("LexiqueLocation",ui->lineEditLexique->text());
    s.setValue("WikiquoteLocation",ui->lineEditWikiquote->text());
    s.setValue("WiktionaryLocation",ui->lineEditWiktionary->text());
    s.setValue("StorageDirectory",ui->lineEditStorageDirectory->text());
}

void DialogConfiguration::Load()
{
    QSettings s;
    ui->lineEditCities->setText(getCitiesLocation());
    ui->lineEditFirstname->setText(getFirstnameLocation());
    ui->lineEditFortune->setText(getFortuneLocation()) ;
    ui->lineEditLexique->setText(getLexiqueLocation());
    ui->lineEditWikiquote->setText(getWikiquoteLocation());
    ui->lineEditWiktionary->setText(getWikionaryLocation());
    ui->lineEditStorageDirectory->setText(s.value("StorageDirectory").toString());
}
