#include "dialoggetallfiles.h"
#include "ui_dialoggetallfiles.h"
#include "dialogconfiguration.h"

#include <QSettings>
#include <QMessageBox>
#include <QFileDialog>
#include <GMarchive.h>
#include <QDir>

DialogGetAllFiles::DialogGetAllFiles(QWidget *parent, Mode mode) :
    QDialog(parent),
    ui(new Ui::DialogGetAllFiles)
{
    ui->setupUi(this);
    connect ( ui->pushButtonAbort,SIGNAL(clicked(bool)),this,SLOT(close()));
    if ( mode == download )
    {
       connect ( ui->pushButtonDownload,SIGNAL(clicked(bool)),this,SLOT(getAllFiles()));

    }
    else
    {
        ui->pushButtonDownload->setText(tr("Decompress"));
        connect (ui->pushButtonDownload,SIGNAL(clicked(bool)),this,SLOT(decompressAll()));
    }
    while ( DialogConfiguration::getStorageDirectory().isEmpty())
    {
        QMessageBox msg(QMessageBox::Warning,tr("Configuration error"),tr("Your StorageDirectory variable is not set in your configuration window. Do you want to set if now ?"),QMessageBox::Yes| QMessageBox::No,this);
        int ret=msg.exec();
        if (ret==QMessageBox::No)
            return;
        else
        {
            QSettings s;
            s.setValue("StorageDirectory",QFileDialog::getExistingDirectory(this,tr("Choose the directory where your download files will be stored"),QDir::homePath()));
        }

    }
}

void DialogGetAllFiles::decompressAll()
{
    Decompress(m_archwikiquote,DialogConfiguration::getWikiquoteLocation(),ui->progressBarWikiquote,ui->spinBoxFilesInWikiquote);
    Decompress(m_archwiktionary,DialogConfiguration::getWikionaryLocation(),ui->progressBarWiktionary,ui->spinBoxFilesInWiktionary);
    Decompress(m_archfirstname,DialogConfiguration::getFirstnameLocation(),ui->progressBarFirstName,ui->spinBoxFilesInFirstname);
    Decompress(m_archlexique,DialogConfiguration::getLexiqueLocation(),ui->progressBarLexique,ui->spinBoxFilesInLexique);
    Decompress(m_archfortune,DialogConfiguration::getFortuneLocation(),ui->progressBarFortune,ui->spinBoxFilesInFortune);
    Decompress(m_archcities,DialogConfiguration::getCitiesLocation(),ui->progressBarCities,ui->spinBoxFilesInCities);
}

void DialogGetAllFiles::getAllFiles()
{
    Download(m_wikiquote,DialogConfiguration::getWikiquoteLocation(),DialogConfiguration::getWikiquoteSize(),ui->progressBarWikiquote,ui->spinBoxFilesInWikiquote);
    Download(m_wiktionary,DialogConfiguration::getWikionaryLocation(),DialogConfiguration::getWikionarySize(),ui->progressBarWiktionary,ui->spinBoxFilesInWiktionary);
    Download(m_firstname,DialogConfiguration::getFirstnameLocation(),DialogConfiguration::getFirstnameSize(),ui->progressBarFirstName,ui->spinBoxFilesInFirstname);
    Download(m_lexique,DialogConfiguration::getLexiqueLocation(),DialogConfiguration::getLexiqueSize(),ui->progressBarLexique,ui->spinBoxFilesInLexique);
    Download(m_fortune,DialogConfiguration::getFortuneLocation(),DialogConfiguration::getFortuneSize(),ui->progressBarFortune,ui->spinBoxFilesInFortune);
    Download(m_cities,DialogConfiguration::getCitiesLocation(),DialogConfiguration::getCitiesSize(),ui->progressBarCities,ui->spinBoxFilesInCities);
}


DialogGetAllFiles::~DialogGetAllFiles()
{
    delete ui;
}


void DialogGetAllFiles::Download(FileDonwload *ptr,QString file,qlonglong size,QProgressBar *pb,QSpinBox *sb)
{
    pb->setMinimum(0);
    pb->setValue(0);
    pb->setMaximum(size);
    ptr =new  FileDonwload(QUrl(file),size,pb,sb,this);
    connect ( ptr,SIGNAL(reading(int)),pb,SLOT(setValue(int)));
    connect (ptr,SIGNAL(Downloaded(int,int,QProgressBar*,QSpinBox*)),this,SLOT(SetValuesAndFileNumber(int,int,QProgressBar *,QSpinBox *)));
}

void DialogGetAllFiles::Decompress(GMArchive *ptr,QString file,QProgressBar *pb,QSpinBox *sb)
{
    pb->setMinimum(0);
    pb->setValue(0);
    QFileInfo fi(file);
    pb->setMaximum(fi.size());
    ptr =new  GMArchive(QUrl(file),size,pb,sb,this);
    connect ( ptr,SIGNAL(reading(int)),pb,SLOT(setValue(int)));
    connect (ptr,SIGNAL(Downloaded(int,int,QProgressBar*,QSpinBox*)),this,SLOT(SetValuesAndFileNumber(int,int,QProgressBar *,QSpinBox *)));
}


void DialogGetAllFiles::SetValuesAndFileNumber(int progressbarvalue, int spinboxvalue,
                                               QProgressBar *pb,QSpinBox *sb)
{
        sb->setValue(spinboxvalue);
        pb->setValue(progressbarvalue);
}

void DialogGetAllFiles::setTotalSize(QString str,int i)
{
    qWarning()<<"received"<<str<<i;
    qWarning()<<"sender"<<sender()->objectName();
}

void DialogGetAllFiles::setValue(QString str,int i)
{
    qWarning()<<"received"<<str<<i;
}
