#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "displaytable.h"
#include "GMarchive.h"

#include <QSettings>
#include <QFileDialog>
#include <QSqlDatabase>
#include <QMessageBox>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    m_dialogConfiguration = new DialogConfiguration(this);

    connect (ui->actionConfiguration,SIGNAL(triggered(bool)),m_dialogConfiguration,SLOT(show()));
    connect (ui->actionGetAllFile,SIGNAL(triggered(bool)),this,SLOT(GetAllFiles()));
    connect (ui->actionMake_Database,SIGNAL(triggered(bool)),this,SLOT(MakeDatabase()));
    connect (ui->actionOpen_Database,SIGNAL(triggered(bool)),this,SLOT(OpenDataBase()));
    connect(ui->actionQuit,SIGNAL(triggered(bool)),this,SLOT(close()));
}



void MainWindow::GetAllFiles()
{
    DialogGetAllFiles d(this);
    d.exec();
}


void MainWindow::DecompressAll()
{
    DialogGetAllFiles d(this,DialogGetAllFiles::decompress);
    d.exec();
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::OpenDataBase()
{
    QSettings s;
    while ( ui->tabWidget->count()>0 ) ui->tabWidget->removeTab(ui->tabWidget->count()-1);
    QString lastdir=s.value("LastDir").toString();
    qDebug()<<lastdir;
    QSqlDatabase db=QSqlDatabase::addDatabase("QSQLITE");
    QString databasefile=QFileDialog::getOpenFileName(this,tr("Choose a database"),lastdir,tr("*.db Sqlite Files"));
    QDir dir(databasefile);
    s.setValue("LastDir",dir.path());
    db.setDatabaseName(databasefile);
    db.open();
    ui->tabWidget->addTab(new DisplayTable("dico",this),"Dico");
    ui->tabWidget->addTab(new DisplayTable("definitions",this),"Definitions");
    ui->tabWidget->addTab(new DisplayTable("citations",this),"Citations");
    ui->tabWidget->addTab(new DisplayTable("synonymes",this),"Synonymes");
}



void MainWindow::MakeDatabase()
{
    DecompressAll();
}
