#ifndef FORMATAGE_H
#define FORMATAGE_H

#include "qdictionnaire.h"

class formatage
{
private:
        QString m_etymologie;
        QString m_expression;
        QString m_antonyme;
        QString m_synonyme;

public:
	formatage();
    ///
    /// \brief EtendChiffreVerbe renvoie "première personne" "deuxième personne" etc...
    /// \param chiffre : est un numéro de 1 à 6
    /// \return  la chaine contant la personne
    ///
	QString EtendChiffreVerbe ( QChar chiffre);
    ///
    /// \brief EtendLettreVerbe renvoie le temps à partir d'une lettre A présent etc
    /// \param lettre est la lettre correspondant au temps
    /// \param verbe est le verbe à conjuguer
    /// \return
    ///
	QString EtendLettreVerbe ( QChar lettre, QString verbe) ;

	QString FormateExpression( QString definition);
    QString FormateEtymologie (QString definition);
    QString FormateDefinition (QString mot,QString definition, QString ajout="");
    ///
    /// \brief FormateSyllabes : renvoie le nombre de syllabes contenue dans le paramètres
    /// \param nbsyllabes : 2 => 2 syllabes 1 =1 syllabe
    /// \return
    ///
	QString FormateSyllabes( QString nbsyllabes );
    ///
    /// \brief FormateGenre à partir d'une lettre f ou m renvoie masculin ou féminin
    /// \param genre : f ou m
    /// \return  le genre en toute lettre
    ///
	QString FormateGenre (QString genre);
	QString FormateCitation ( QString mot, QString phrase, QString auteur, QString rubrique);
    QString SupprimeEtiquette ( QString Etiquette, QString definition);
    QString ExtraitRubrique ( QString Etiquette, QString definition, QString *chaineretournee, QString Titre="");


    /// accesseurs
    QString getEtymologie() { return m_etymologie ;}
    QString getExpression() { return m_expression ;}
    QString getAntonyme(){ return m_antonyme ;}
    QString getSynonyme(){ return m_synonyme ;}
    ///
    /// \brief CodePays transforme les code langue du type ar en arabe
    /// \param code
    /// \return le code en texte plein
    ///
    QString CodePays(QString code);
    QString MakeTitle(QString definition);
    QStringList FormateListe(QString definition) ;
    ///
    /// \brief ExtraitFrancais  supprime toutes les partie comprenant == {{langue|quelquechose} ==
    /// où quelque chose n'est pas fr. Une fois que langue|fr est rencontré on supprime tout à partir des autres occurences.
    /// \param definition la chaine correspondant à la définition. Si on ne trouve pas de {{langue|fr}} rien n'est supprimé
    /// \return la chaine avec uniquement la définition en français
    ///
    QString ExtraitFrancais( QString definition);
    ///
    /// \brief UcFirst renvoie la première lettre en majuscule
    /// \param sentence une chaine de caractères
    /// \return la chaine de caractères dont la première lettre est forcée en majuscule
    ///
    QString UcFirst(QString sentence);

    ///
    /// \brief WikipediaFormate divers formatages propres à wikipedia
    /// \param chaine en entrée
    /// \return chaine en sortie
    ///
    QString WikipediaFormate( QString chaine);

};

#endif // FORMATAGE_H
